===================
Configuration Guide
===================

The configuration for DEEPaaS is handled by the ``deepaas.conf`` configuration
file, described below.

* :doc:`Config Reference <config>`: A complete reference of all
  configuration options available in the ``deepaas.conf`` file.

* :doc:`Sample Config File <sample>`: A sample config
  file with inline documentation.

